﻿using Exam.Application.Interface.Exam;
using Exam.Share;
using Exam.Share.Dtos.ExamManage;
using Exam.Share.ViewResponses.Exam;
using Hotline.Application.Exam.Constants.ApiRoutes;
using Hotline.Share.Dtos.ExamManages;
using Hotline.Share.Requests.Exam;
using Hotline.Share.ViewResponses.Exam;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;

namespace Hotline.Api.Controllers.Exam
{
    public class UserExamController : BaseController
    {
        private readonly IUserExamService _userExamService;

        public UserExamController(IUserExamService userExamService)
        {
            this._userExamService = userExamService;
        }

        /// <summary>
        /// 获取我的考试结果
        /// </summary>
        /// <param name="userExamPagedRequest"></param>
        /// <returns></returns>
        [HttpPost(UserExamApiRoute.GetPagedList)]
        public async Task<UserExamResultPageViewResponse> GetPagedList([FromBody] UserExamPagedRequest userExamPagedRequest)
        {
            return await _userExamService.GetPagedListAsync(userExamPagedRequest) as UserExamResultPageViewResponse;
        }

        /// <summary>
        /// 开始考试
        /// </summary>
        /// <param name="addUserExamDto"></param>
        /// <returns></returns>
        [HttpPost(UserExamApiRoute.Start)]
        public async Task Start([FromBody] StartUserExamDto startUserExamDto)
        {
            await _userExamService.StartUserExamAsync(startUserExamDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 获取试题类型分组
        /// </summary>
        /// <param name="examQuestionGroupRequest"></param>
        /// <returns></returns>
        [HttpGet(UserExamApiRoute.GetExamQuestionGroup)]
        public async Task<List<ExamQuestionViewResponse>> GetExamQuestionGroup([FromQuery]ExamQuestionGroupRequest examQuestionGroupRequest)
        {
            return await _userExamService.GetExamQuestionViewResponses(examQuestionGroupRequest);
        }

        /// <summary>
        /// 获取试题详情
        /// </summary>
        /// <param name="examQuestionRequest"></param>
        /// <returns></returns>
        [HttpGet(UserExamApiRoute.GetExamQuestion)]
        public async Task<ExamQuestionDto> GetExamQuestion([FromQuery]ExamQuestionRequest examQuestionRequest)
        {
            return await _userExamService.GetExamQuestionDto(examQuestionRequest);
        }

        /// <summary>
        /// 考试
        /// </summary>
        /// <param name="addUserExamItemDto"></param>
        /// <returns></returns>
        [HttpPost(UserExamApiRoute.Exam)]
        public async Task<UserExamQuestionDto> Exam([FromBody] AddUserExamItemDto addUserExamItemDto)
        {
            return await _userExamService.ExamAsync(addUserExamItemDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 更新考试
        /// </summary>
        /// <param name="updateUserExamItemDto"></param>
        /// <returns></returns>
        [HttpPut(UserExamApiRoute.UpdateExam)]
        public async Task<UserExamQuestionDto> UpdateExam([FromBody]UpdateUserExamItemDto updateUserExamItemDto)
        {
           return await _userExamService.UpdateExamAsync(updateUserExamItemDto,HttpContext.RequestAborted);
        }

        /// <summary>
        /// 提交考试
        /// </summary>
        /// <param name="submitExamDto"></param>
        /// <returns></returns>
        [HttpPost(UserExamApiRoute.Submit)]
        public async Task Submit([FromBody] SubmitExamDto submitExamDto)
        {
            await _userExamService.SubmitAsync(submitExamDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 阅卷
        /// </summary>
        /// <param name="gradingExtamDto"></param>
        /// <returns></returns>
        [HttpPost(UserExamApiRoute.Grading)]
        public async Task<GradingExamQuestionDto> Grading([FromBody] GradingExtamItemDto gradingExtamItemDto)
        {
          return  await _userExamService.GradingAsync(gradingExtamItemDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 完成阅卷
        /// </summary>
        /// <param name="gradingExtamDto"></param>
        /// <returns></returns>
        [HttpPost(UserExamApiRoute.CompleteGrading)]
        public async Task CompleteGrading([FromBody] GradingExamDto gradingExtamDto)
        {
            await _userExamService.CompleteGradingAsync(gradingExtamDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 获取阅卷试题
        /// </summary>
        /// <param name="gradingExamRequest"></param>
        /// <returns></returns>
        [HttpPost(UserExamApiRoute.GetGradingQuestions)]
        public async Task<List<GradingExamQuestionDto>> GetGradingQuestions([FromBody] GradingExamRequest gradingExamRequest)
        {
            return await _userExamService.GetGradingExamQuestion(gradingExamRequest);
        }
    }
}
